==> estateplat-common-1.2.4-20220607.092754-1035-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzSydjzxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/5/10
 * @description 省级信息共享-民政部-收养登记证信息
 */
@Table(name = "xxgx_mz_sydjzxx")
public class XxgxMzSydjzxx {
    @Id
    private String sydjid;
    private String msyrxm;//男收养人姓名
    private String msyrzjlx;//男收养人证件类型
    private String msyrzjlxmc;//男收养人证件类型名称
    private String msyrsfzjh;//男收养人身份证件号
    private String msyrgjdm;//男收养人国籍代码
    private String msyrgjmc;//男收养人国籍名称
    private Date msyrcsrq;//男收养人出生日期
    private String wsyrxm;//女收养人姓名
    private String wsyrzjlx;//女收养人证件类型
    private String wsyrzjlxmc;//女收养人证件类型名称
    private String wsyrsfzjh;//女收养人身份证件号
    private String wsyrgjdm;//女收养人国籍代码
    private String wsyrgjmc;//女收养人国籍名称
    private Date wsyrcsrq;//女收养人出生日期
    private String bsyrxm;//被收养人姓名
    private String bsyrsfzh;//被收养人身份证号
    private String bsyrgjdm;//被收养人国籍代码
    private String bsyrgjmc;//被收养人国籍名称
    private String bsyrxb;//被收养人性别
    private String bsyrxbmc;//被收养人性别名称
    private String bsyrcsrq;//被收养人出生日期
    private String djlx;//登记类型
    private String djlxmc;//登记类型名称
    private Date djrq;//登记日期
    private String djjg;//登记机关
    private String djjgmc;//登记机关名称
    private String proid;//项目id
    private Date cxsj;//查询时间


    public String getSydjid() {
        return sydjid;
    }

    public void setSydjid(String sydjid) {
        this.sydjid = sydjid;
    }

    public String getMsyrxm() {
        return msyrxm;
    }

    public void setMsyrxm(String msyrxm) {
        this.msyrxm = msyrxm;
    }

    public String getMsyrzjlx() {
        return msyrzjlx;
    }

    public void setMsyrzjlx(String msyrzjlx) {
        this.msyrzjlx = msyrzjlx;
    }

    public String getMsyrzjlxmc() {
        return msyrzjlxmc;
    }

    public void setMsyrzjlxmc(String msyrzjlxmc) {
        this.msyrzjlxmc = msyrzjlxmc;
    }

    public String getMsyrsfzjh() {
        return msyrsfzjh;
    }

    public void setMsyrsfzjh(String msyrsfzjh) {
        this.msyrsfzjh = msyrsfzjh;
    }

    public String getMsyrgjdm() {
        return msyrgjdm;
    }

    public void setMsyrgjdm(String msyrgjdm) {
        this.msyrgjdm = msyrgjdm;
    }

    public String getMsyrgjmc() {
        return msyrgjmc;
    }

    public void setMsyrgjmc(String msyrgjmc) {
        this.msyrgjmc = msyrgjmc;
    }

    public Date getMsyrcsrq() {
        return msyrcsrq;
    }

    public void setMsyrcsrq(Date msyrcsrq) {
        this.msyrcsrq = msyrcsrq;
    }

    public String getWsyrxm() {
        return wsyrxm;
    }

    public void setWsyrxm(String wsyrxm) {
        this.wsyrxm = wsyrxm;
    }

    public String getWsyrzjlx() {
        return wsyrzjlx;
    }

    public void setWsyrzjlx(String wsyrzjlx) {
        this.wsyrzjlx = wsyrzjlx;
    }

    public String getWsyrzjlxmc() {
        return wsyrzjlxmc;
    }

    public void setWsyrzjlxmc(String wsyrzjlxmc) {
        this.wsyrzjlxmc = wsyrzjlxmc;
    }

    public String getWsyrsfzjh() {
        return wsyrsfzjh;
    }

    public void setWsyrsfzjh(String wsyrsfzjh) {
        this.wsyrsfzjh = wsyrsfzjh;
    }

    public String getWsyrgjdm() {
        return wsyrgjdm;
    }

    public void setWsyrgjdm(String wsyrgjdm) {
        this.wsyrgjdm = wsyrgjdm;
    }

    public String getWsyrgjmc() {
        return wsyrgjmc;
    }

    public void setWsyrgjmc(String wsyrgjmc) {
        this.wsyrgjmc = wsyrgjmc;
    }

    public Date getWsyrcsrq() {
        return wsyrcsrq;
    }

    public void setWsyrcsrq(Date wsyrcsrq) {
        this.wsyrcsrq = wsyrcsrq;
    }

    public String getBsyrxm() {
        return bsyrxm;
    }

    public void setBsyrxm(String bsyrxm) {
        this.bsyrxm = bsyrxm;
    }

    public String getBsyrsfzh() {
        return bsyrsfzh;
    }

    public void setBsyrsfzh(String bsyrsfzh) {
        this.bsyrsfzh = bsyrsfzh;
    }

    public String getBsyrgjdm() {
        return bsyrgjdm;
    }

    public void setBsyrgjdm(String bsyrgjdm) {
        this.bsyrgjdm = bsyrgjdm;
    }

    public String getBsyrgjmc() {
        return bsyrgjmc;
    }

    public void setBsyrgjmc(String bsyrgjmc) {
        this.bsyrgjmc = bsyrgjmc;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjlxmc() {
        return djlxmc;
    }

    public void setDjlxmc(String djlxmc) {
        this.djlxmc = djlxmc;
    }

    public Date getDjrq() {
        return djrq;
    }

    public void setDjrq(Date djrq) {
        this.djrq = djrq;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDjjgmc() {
        return djjgmc;
    }

    public void setDjjgmc(String djjgmc) {
        this.djjgmc = djjgmc;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getBsyrxb() {
        return bsyrxb;
    }

    public void setBsyrxb(String bsyrxb) {
        this.bsyrxb = bsyrxb;
    }

    public String getBsyrxbmc() {
        return bsyrxbmc;
    }

    public void setBsyrxbmc(String bsyrxbmc) {
        this.bsyrxbmc = bsyrxbmc;
    }

    public String getBsyrcsrq() {
        return bsyrcsrq;
    }

    public void setBsyrcsrq(String bsyrcsrq) {
        this.bsyrcsrq = bsyrcsrq;
    }
}

==> estateplat-common-1.2.4-20230511.082623-1171-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzSydjzxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/5/10
 * @description 省级信息共享-民政部-收养登记证信息
 */
@Table(name = "xxgx_mz_sydjzxx")
public class XxgxMzSydjzxx {
    @Id
    private String sydjid;
    private String msyrxm;//男收养人姓名
    private String msyrzjlx;//男收养人证件类型
    private String msyrzjlxmc;//男收养人证件类型名称
    private String msyrsfzjh;//男收养人身份证件号
    private String msyrgjdm;//男收养人国籍代码
    private String msyrgjmc;//男收养人国籍名称
    private Date msyrcsrq;//男收养人出生日期
    private String wsyrxm;//女收养人姓名
    private String wsyrzjlx;//女收养人证件类型
    private String wsyrzjlxmc;//女收养人证件类型名称
    private String wsyrsfzjh;//女收养人身份证件号
    private String wsyrgjdm;//女收养人国籍代码
    private String wsyrgjmc;//女收养人国籍名称
    private Date wsyrcsrq;//女收养人出生日期
    private String bsyrxm;//被收养人姓名
    private String bsyrsfzh;//被收养人身份证号
    private String bsyrgjdm;//被收养人国籍代码
    private String bsyrgjmc;//被收养人国籍名称
    private String bsyrxb;//被收养人性别
    private String bsyrxbmc;//被收养人性别名称
    private String bsyrcsrq;//被收养人出生日期
    private String djlx;//登记类型
    private String djlxmc;//登记类型名称
    private Date djrq;//登记日期
    private String djjg;//登记机关
    private String djjgmc;//登记机关名称
    private String sydjzh;//收养登记证号
    private String proid;//项目id
    private Date cxsj;//查询时间


    public String getSydjid() {
        return sydjid;
    }

    public void setSydjid(String sydjid) {
        this.sydjid = sydjid;
    }

    public String getMsyrxm() {
        return msyrxm;
    }

    public void setMsyrxm(String msyrxm) {
        this.msyrxm = msyrxm;
    }

    public String getMsyrzjlx() {
        return msyrzjlx;
    }

    public void setMsyrzjlx(String msyrzjlx) {
        this.msyrzjlx = msyrzjlx;
    }

    public String getMsyrzjlxmc() {
        return msyrzjlxmc;
    }

    public void setMsyrzjlxmc(String msyrzjlxmc) {
        this.msyrzjlxmc = msyrzjlxmc;
    }

    public String getMsyrsfzjh() {
        return msyrsfzjh;
    }

    public void setMsyrsfzjh(String msyrsfzjh) {
        this.msyrsfzjh = msyrsfzjh;
    }

    public String getMsyrgjdm() {
        return msyrgjdm;
    }

    public void setMsyrgjdm(String msyrgjdm) {
        this.msyrgjdm = msyrgjdm;
    }

    public String getMsyrgjmc() {
        return msyrgjmc;
    }

    public void setMsyrgjmc(String msyrgjmc) {
        this.msyrgjmc = msyrgjmc;
    }

    public Date getMsyrcsrq() {
        return msyrcsrq;
    }

    public void setMsyrcsrq(Date msyrcsrq) {
        this.msyrcsrq = msyrcsrq;
    }

    public String getWsyrxm() {
        return wsyrxm;
    }

    public void setWsyrxm(String wsyrxm) {
        this.wsyrxm = wsyrxm;
    }

    public String getWsyrzjlx() {
        return wsyrzjlx;
    }

    public void setWsyrzjlx(String wsyrzjlx) {
        this.wsyrzjlx = wsyrzjlx;
    }

    public String getWsyrzjlxmc() {
        return wsyrzjlxmc;
    }

    public void setWsyrzjlxmc(String wsyrzjlxmc) {
        this.wsyrzjlxmc = wsyrzjlxmc;
    }

    public String getWsyrsfzjh() {
        return wsyrsfzjh;
    }

    public void setWsyrsfzjh(String wsyrsfzjh) {
        this.wsyrsfzjh = wsyrsfzjh;
    }

    public String getWsyrgjdm() {
        return wsyrgjdm;
    }

    public void setWsyrgjdm(String wsyrgjdm) {
        this.wsyrgjdm = wsyrgjdm;
    }

    public String getWsyrgjmc() {
        return wsyrgjmc;
    }

    public void setWsyrgjmc(String wsyrgjmc) {
        this.wsyrgjmc = wsyrgjmc;
    }

    public Date getWsyrcsrq() {
        return wsyrcsrq;
    }

    public void setWsyrcsrq(Date wsyrcsrq) {
        this.wsyrcsrq = wsyrcsrq;
    }

    public String getBsyrxm() {
        return bsyrxm;
    }

    public void setBsyrxm(String bsyrxm) {
        this.bsyrxm = bsyrxm;
    }

    public String getBsyrsfzh() {
        return bsyrsfzh;
    }

    public void setBsyrsfzh(String bsyrsfzh) {
        this.bsyrsfzh = bsyrsfzh;
    }

    public String getBsyrgjdm() {
        return bsyrgjdm;
    }

    public void setBsyrgjdm(String bsyrgjdm) {
        this.bsyrgjdm = bsyrgjdm;
    }

    public String getBsyrgjmc() {
        return bsyrgjmc;
    }

    public void setBsyrgjmc(String bsyrgjmc) {
        this.bsyrgjmc = bsyrgjmc;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjlxmc() {
        return djlxmc;
    }

    public void setDjlxmc(String djlxmc) {
        this.djlxmc = djlxmc;
    }

    public Date getDjrq() {
        return djrq;
    }

    public void setDjrq(Date djrq) {
        this.djrq = djrq;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDjjgmc() {
        return djjgmc;
    }

    public void setDjjgmc(String djjgmc) {
        this.djjgmc = djjgmc;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getBsyrxb() {
        return bsyrxb;
    }

    public void setBsyrxb(String bsyrxb) {
        this.bsyrxb = bsyrxb;
    }

    public String getBsyrxbmc() {
        return bsyrxbmc;
    }

    public void setBsyrxbmc(String bsyrxbmc) {
        this.bsyrxbmc = bsyrxbmc;
    }

    public String getBsyrcsrq() {
        return bsyrcsrq;
    }

    public void setBsyrcsrq(String bsyrcsrq) {
        this.bsyrcsrq = bsyrcsrq;
    }

    public String getSydjzh() {
        return sydjzh;
    }

    public void setSydjzh(String sydjzh) {
        this.sydjzh = sydjzh;
    }
}
